summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolderindex.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfolderindex.h')
-rw-r--r--kmail/kmfolderindex.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmail/kmfolderindex.h b/kmail/kmfolderindex.h
index 28743c497..b0682ff00 100644
--- a/kmail/kmfolderindex.h
+++ b/kmail/kmfolderindex.h
@@ -39,7 +39,7 @@ class KMFolderIndex: public FolderStorage
Q_OBJECT
TQ_OBJECT
//TODO:Have to get rid of this friend declaration and add necessary pure
//virtuals to kmfolder.h so that KMMsgBase::tqparent() can be a plain KMFolder
//rather than a KMFolderIndex. Need this for database indices.
friend class ::KMMsgBase;
public:
@@ -53,8 +53,8 @@ public:
IndexTooOld
};
- /** Usually a tqparent is given. But in some cases there is no
- fitting tqparent object available. Then the name of the folder
+ /** Usually a parent is given. But in some cases there is no
+ fitting parent object available. Then the name of the folder
is used as the absolute path to the folder file. */
KMFolderIndex(KMFolder* folder, const char* name=0);
virtual ~KMFolderIndex();
@@ -39,7 +39,7 @@ class KMFolderIndex: public FolderStorage
TQ_OBJECT
//TODO:Have to get rid of this friend declaration and add necessary pure
- //virtuals to kmfolder.h so that KMMsgBase::tqparent() can be a plain KMFolder
+ //virtuals to kmfolder.h so that KMMsgBase::parent() can be a plain KMFolder
//rather than a KMFolderIndex. Need this for database indices.
friend class ::KMMsgBase;